# sacredfig

SacredFig is a Python library that provides opinionated styles for scientific figures in matplotlib.


## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install SacredFig.

```bash
pip install sacredfig